from ochrona.parsers.conda import CondaFile
from ochrona.parsers.constraints import ConstraintsFile
from ochrona.parsers.pipfile import Pipfile
from ochrona.parsers.poetry import PoetryFile
from ochrona.parsers.requirements import RequirementsFile
from ochrona.parsers.setup_ import SetupFile
from ochrona.parsers.tox import ToxFile


class Parsers:
    @property
    def conda(self):
        return CondaFile

    @property
    def constraints(self):
        return ConstraintsFile

    @property
    def pipfile(self):
        return Pipfile

    @property
    def poetry(self):
        return PoetryFile

    @property
    def requirements(self):
        return RequirementsFile

    @property
    def setup(self):
        return SetupFile

    @property
    def tox(self):
        return ToxFile



from configparser import ConfigParser, NoOptionError
from io import StringIO
from typing import List

from ochrona.const import TOX_LINKED_REQUIREMENTS, INVALID_TOX_LINES, TOX_INI
from ochrona.parsers.requirements import RequirementsFile


class ToxFile:
    @staticmethod
    def parse(file_path: str) -> List[str]:
        """
        Parses a tox.ini into a list of requirements.

        :param file_path: tox.ini path
        :return: list<str> list of dependencies ['dependency==semvar']
        """
        dependencies = []
        with open(file_path) as tox:
            parser = ConfigParser()
            parser.read_file(tox)
            for section in parser.sections():
                try:
                    deps = parser.get(section=section, option="deps")
                    for _, line in enumerate(deps.splitlines()):
                        if line.startswith(TOX_LINKED_REQUIREMENTS):
                            path = ToxFile._tox_path(file_path)
                            req_file_name = line.replace(TOX_LINKED_REQUIREMENTS, "")
                            return RequirementsFile.parse(f"{path}{req_file_name}")
                        elif not any([line.startswith(i) for i in INVALID_TOX_LINES]):
                            if ":" in line:
                                # requirement is specified with an environment
                                dependencies.append(line.split(":")[-1].strip())
                            else:
                                if line != "":
                                    # plain requirement
                                    dependencies.append(line)
                        else:
                            pass  # did not find valid line to parse
                except NoOptionError:
                    pass
        return dependencies

    @staticmethod
    def _tox_path(tox_file_path):
        return tox_file_path.replace(TOX_INI, "")



import yaml
from typing import List

from ochrona.exceptions import OchronaFileException


class CondaFile:
    @staticmethod
    def parse(file_path: str) -> List[str]:
        """
        Parses a conda.yml into a list of requirements.
        NOTE: This currently only returns pip-based dependencies.

        :param file_path: conda.yml path
        :return: list<str> list of dependencies ['dependency==semvar']
        """
        try:
            dependencies = []
            with open(file_path) as conda_file:
                data = yaml.safe_load(conda_file)
                if (
                    data
                    and isinstance(data, dict)
                    and "dependencies" in data
                    and isinstance(data.get("dependencies"), list)
                ):
                    for line in data.get("dependencies", []):
                        if isinstance(line, dict) and "pip" in line:
                            for _, req in enumerate(line.get("pip", {})):
                                dependencies.append(req)
                        else:
                            # Non-pip specified dependencies
                            continue
            return dependencies
        except yaml.YAMLError as ex:
            raise OchronaFileException(f"Yaml error when parsion {file_path}") from ex
        except OSError as ex:
            raise OchronaFileException(f"OS error when parsing {file_path}") from ex



# -*- coding: utf-8 -*-
"""
Ochrona-cli
:author: ascott
"""

import datetime
import json
import os
import sys
import textwrap

import xml.etree.ElementTree as ET
from xml.dom import minidom

from typing import Any, Dict, List, Optional

from ochrona.config import OchronaConfig
from ochrona.logger import OchronaLogger


class OchronaReporter:
    def __init__(self, logger: OchronaLogger, config: OchronaConfig):
        self._config = config
        self.logger = logger
        self._report_type = self._config.report_type
        self._report_location = self._config.report_location
        self._exit = self._config.exit
        self._ignore = self._config.ignore

    def report_collector(self, sources: List[str], results: List[Dict[str, Any]]):
        """
        Collects and generates each report and exits the program
        :param sources: list of file locations
        :param results: results for each file scan
        :return: sys.exit -1 if vulns are discovered
        """
        reports = []
        for index, (source, result) in enumerate(zip(sources, results)):
            if "confirmed_vulnerabilities" in result:
                result["confirmed_vulnerabilities"] = list(
                    filter(
                        lambda cv: self._filter_ignored_vuln(cv),
                        result.get("confirmed_vulnerabilities", []),
                    )
                )
            else:
                result["confirmed_vulnerabilities"] = []
            result["potential_vulnerabilities"] = result.get(
                "potential_vulnerabilities", []
            )
            reports.append(self.generate_report(source, result, index, len(sources)))
        for result in results:
            if (
                "confirmed_vulnerabilities" in result
                and result["confirmed_vulnerabilities"]
            ):
                if not self._exit:
                    sys.exit(-1)
                sys.exit(0)

    def generate_report(
        self, source: str, result: Dict[str, Any], index: int, total: int
    ):
        """
        Handles report generate based on configured type.

        :param source: str - The source of the data
        :param result: dict - The results from the API
        :param index: int - the index of the file results
        :param total: int - the total number of file results
        :return:
        """
        if self._report_type in ["BASIC", "FULL"]:
            BaseReport.print_report_number(index, total, self._config.color_output)
            BaseReport.print_report_source(source, self._config.color_output)
            if (
                not result["confirmed_vulnerabilities"]
                and not result["potential_vulnerabilities"]
            ):
                BaseReport.print_no_vulns(self._config.color_output)
            else:
                # TODO potential_vulnerabilities will be removed
                for finding in result.get("potential_vulnerabilities", []):
                    BasicReport.print_vuln_finding(
                        finding, False, self._config.color_output
                    ) if self._config.report_type == "BASIC" else FullReport.print_vuln_finding(
                        finding, False, self._config.color_output
                    )
                for finding in result.get("confirmed_vulnerabilities", []):
                    BasicReport.print_vuln_finding(
                        finding, True, self._config.color_output
                    ) if self._config.report_type == "BASIC" else FullReport.print_vuln_finding(
                        finding, True, self._config.color_output
                    )
            BaseReport.print_new_line()
        elif self._report_type == "JSON":
            report = result.get("confirmed_vulnerabilities")
            # TODO potential_vulnerabilities will be removed
            if not report:
                report = result.get("potential_vulnerabilities")

            if report:
                if not self._report_location:
                    JSONReport.display_report(report, source, total, index)
                else:
                    JSONReport.save_report_to_file(
                        report, self._report_location, source, index
                    )
            elif not report and not self._report_location:
                JSONReport.display_report([], source, total, index)
            else:
                JSONReport.save_report_to_file([], self._report_location, source, index)
        elif self._report_type == "XML":
            if not self._report_location:
                XMLReport.display_report(result, source, total, index)
            else:
                XMLReport.save_report_to_file(
                    result, self._report_location, source, index
                )

    def _filter_ignored_vuln(self, confirmed_vuln: Dict[str, Any]) -> bool:
        """
        Returns False is the confirmed vuln matches an ignore rule
        :param confirmed_vuln: dict - Confirmed vulnerability from API results.
        :return: bool
        """
        if not confirmed_vuln or not self._ignore:
            return True
        for cv in self._ignore:
            if cv == confirmed_vuln.get("cve_id") or cv == confirmed_vuln.get("name"):
                return False
        return True


class BaseReport:
    INFO = "\033[94m"
    PASS = "\033[92m"
    WARNING = "\033[93m"
    ERROR = "\033[91m"
    ENDC = "\033[0m"
    REPORT_LINE_BREAK = f"{INFO}╞{'=' * 100}╡{ENDC}"
    REPORT_ROW_BREAK = f"{INFO}╞{'-' * 100}╡{ENDC}"
    NEWLINE = "\n"
    NO = ""

    @staticmethod
    def print_report_number(index: int, total: int, color: bool = True):
        print(
            f"{BaseReport.INFO if color else BaseReport.NO}Report {index + 1} of {total}{BaseReport.ENDC if color else BaseReport.NO}"
        )

    @staticmethod
    def print_new_line():
        print(BaseReport.NEWLINE)

    @staticmethod
    def print_report_source(source: str, color: bool = True):
        print(
            f"{BaseReport.INFO if color else BaseReport.NO}╞{'=' * 100}╡{BaseReport.ENDC if color else BaseReport.NO}"
        )
        print(
            f"{BaseReport.INFO if color else BaseReport.NO}| Source: {source}{BaseReport.ENDC if color else BaseReport.NO}"
        )
        print(
            f"{BaseReport.INFO if color else BaseReport.NO}╞{'=' * 100}╡{BaseReport.ENDC if color else BaseReport.NO}"
        )

    @staticmethod
    def print_no_vulns(color: bool = True):
        print(
            f"{BaseReport.INFO if color else BaseReport.NO}|{BaseReport.PASS if color else BaseReport.NO} ✅  No Vulnerabilities detected{BaseReport.ENDC if color else BaseReport.NO}"
        )
        print(
            f"{BaseReport.INFO if color else BaseReport.NO}╞{'=' * 100}╡{BaseReport.ENDC if color else BaseReport.NO}"
        )


class BasicReport(BaseReport):
    """
    Basic Report
        - Includes package name, current version, affected version(s), CPE, Severity

    This report can be logged to stdout
    """

    @staticmethod
    def print_vuln_finding(
        finding: Dict[str, Any], confirmed: bool, color: bool = True
    ):
        INFO = BaseReport.INFO if color else BaseReport.NO
        ERROR = BaseReport.ERROR if color else BaseReport.NO
        WARNING = BaseReport.WARNING if color else BaseReport.NO
        ENDC = BaseReport.ENDC if color else BaseReport.NO
        ROW_BREAK = f"{INFO}╞{'-' * 100}╡{ENDC}"
        LINE_BREAK = f"{INFO}╞{'=' * 100}╡{ENDC}"

        if confirmed:
            print(f"{INFO}|{ERROR} ⚠️  Vulnerability Detected!{ENDC}")
        else:
            print(f"{INFO}|{WARNING} ⚠️  [Potential] Vulnerability Detected!{ENDC}")
        print(ROW_BREAK)
        print(f"{INFO}| Package -- {finding.get('name')}{ENDC}")
        print(ROW_BREAK)
        print(f"{INFO}| Installed Version -- {finding.get('found_version')}{ENDC}")
        print(ROW_BREAK)
        print(f"{INFO}| CVE -- {finding.get('cve_id')}{ENDC}")
        print(ROW_BREAK)
        print(f"{INFO}| Severity -- {finding.get('ochrona_severity_score')} {ENDC}")
        print(ROW_BREAK)
        affected_versions = ", ".join(
            [
                f"{f.get('operator')}{f.get('version_value')}"
                for f in finding.get("affected_versions", [])
            ]
        )
        print(
            textwrap.fill(
                f"{INFO}| Affected Versions -- \n{affected_versions}{ENDC}",
                100,
            )
        )
        print(ROW_BREAK)
        print(LINE_BREAK)


class FullReport(BaseReport):
    """
    Full Report
        - Includes package name, current version, affected version(s), CPE,
                 Severity, Description, References, Publish Date

    This report can be logged to stdout
    """

    @staticmethod
    def print_vuln_finding(
        finding: Dict[str, Any], confirmed: bool, color: bool = True
    ):
        INFO = BaseReport.INFO if color else BaseReport.NO
        ERROR = BaseReport.ERROR if color else BaseReport.NO
        WARNING = BaseReport.WARNING if color else BaseReport.NO
        ENDC = BaseReport.ENDC if color else BaseReport.NO
        ROW_BREAK = f"{INFO}╞{'-' * 100}╡{ENDC}"
        LINE_BREAK = f"{INFO}╞{'=' * 100}╡{ENDC}"

        if confirmed:
            print(f"{INFO}|{ERROR} ⚠️  Vulnerability Detected!{ENDC}")
        else:
            print(f"{INFO}|{WARNING} ⚠️  [Potential] Vulnerability Detected!{ENDC}")
        print(ROW_BREAK)
        print(f"{INFO}| Package -- {finding.get('name')}{ENDC}")
        print(ROW_BREAK)
        print(f"{INFO}| Installed Version -- {finding.get('found_version')}{ENDC}")
        print(ROW_BREAK)

        print(
            textwrap.fill(
                f"{INFO}| Reason -- {finding.get('reason')}{ENDC}",
                100,
            )
        )
        print(ROW_BREAK)
        print(f"{INFO}| CVE -- {finding.get('cve_id')}{ENDC}")
        print(ROW_BREAK)
        print(
            f"{INFO}| Vulnerability Publish Date -- {finding.get('publish_date')}{ENDC}"
        )
        print(ROW_BREAK)
        print(f"{INFO}| Severity -- {finding.get('ochrona_severity_score')} {ENDC}")
        print(ROW_BREAK)
        print(
            textwrap.fill(
                f"{INFO}| Description -- {finding.get('description')}{ENDC}",
                100,
            )
        )
        print(ROW_BREAK)
        print(f"{INFO}| License -- {finding.get('license')} {ENDC}")
        print(ROW_BREAK)
        affected_versions = ", ".join(
            [
                f"{f.get('operator')}{f.get('version_value')}"
                for f in finding.get("affected_versions", [])
            ]
        )
        print(
            textwrap.fill(
                f"{INFO}| Affected Version(s) -- \n{affected_versions}{ENDC}",
                100,
            )
        )
        print(ROW_BREAK)
        references = "\n\t".join(finding["references"])
        print(f"{INFO}| References -- \n\t{references} {ENDC}")
        print(LINE_BREAK)
        print(LINE_BREAK)


class JSONReport(BaseReport):
    """
    JSON report
        - Includes full API findings and metadata in json format.

    This report can be logged to stdout
    """

    @staticmethod
    def display_report(
        result: List[Dict[str, Any]], source: str, total: int, index: int
    ):
        BaseReport.print_report_number(index, total)
        BaseReport.print_report_source(source)
        print(JSONReport.generate_report_body(result, source))

    @staticmethod
    def save_report_to_file(
        result: List[Dict[str, Any]], location: str, source: str, index: int
    ):
        with open(
            JSONReport.generate_report_filename(location, source, index), "w"
        ) as f:
            f.write(JSONReport.generate_report_body(result, source))

    @staticmethod
    def generate_report_body(result: List[Dict[str, Any]], source: str) -> str:
        report = {
            "meta": {
                "source": str(source),
                "timestamp": datetime.datetime.now().isoformat(),
            },
            "findings": result,
        }
        return json.dumps(report, indent=4)

    @staticmethod
    def generate_report_filename(location: str, source: str, index: int) -> str:
        return f"{location}/{index+1}_{os.path.basename(source).lower()}_results.json"


class XMLReport(BaseReport):
    """
    XML report
        - Includes only discovered vulnerabilities
    This report can be logged to stdout
    """

    @staticmethod
    def display_report(result: Dict[str, Any], source: str, total: int, index: int):
        BaseReport.print_report_number(index, total)
        BaseReport.print_report_source(source)
        print(XMLReport.generate_report_body(result, source))

    @staticmethod
    def save_report_to_file(
        result: Dict[str, Any], location: str, source: str, index: int
    ):
        with open(
            XMLReport.generate_report_filename(location, source, index), "w"
        ) as f:
            f.write(XMLReport.generate_report_body(result, source))

    @staticmethod
    def generate_report_body(result: Dict[str, Any], source: str) -> str:
        suites = ET.Element("testsuites")
        suite = ET.SubElement(suites, "testsuite")
        suite.set("tests", str(len(result.get("flat_list", []))))
        props = ET.SubElement(suite, "properties")
        source_prop = ET.SubElement(props, "property")
        source_prop.set("name", "source")
        source_prop.set("value", str(source))
        ts_prop = ET.SubElement(props, "property")
        ts_prop.set("name", "timestamp")
        ts_prop.set("value", datetime.datetime.now().isoformat())
        for dep in result.get("flat_list", []):
            case = ET.SubElement(suite, "testcase")
            case.set("classname", "ochronaDependencyVulnCheck")
            case.set("name", dep)
        if "confirmed_vulnerabilities" in result:
            for vuln in result.get("confirmed_vulnerabilities", []):
                case = list(
                    filter(
                        lambda x: x.get("name") == vuln.get("found_version"),
                        list(suite.iter()),
                    )
                )[0]
                failure = ET.SubElement(case, "failure")
                failure.set("type", "confirmed_vulnerability")
                failure.text = f"Package name: {vuln.get('name')}\nVulnerability description: {vuln.get('description')}\nCVE: {vuln.get('cve_id')}\nSeverity: {vuln.get('ochrona_severity_score')}"
        return minidom.parseString(ET.tostring(suites)).toprettyxml(indent="   ")

    @staticmethod
    def generate_report_filename(location: str, source: str, index: int) -> str:
        return f"{location}/{index + 1}_{os.path.basename(source).lower()}_results.xml"


class HTMLReport(BaseReport):
    # TODO
    pass



from typing import List

from ochrona.exceptions import OchronaFileException


class ConstraintsFile:
    @staticmethod
    def parse(file_path: str) -> List[str]:
        """
        Parses a constraints.txt style file into a list of requirements.

        :param file_path: constraints*.txt file path.
        :return: list<str> list of dependencies ['dependency==semvar']
        """
        try:
            with open(file_path) as rfile:
                return [line.rstrip("\n") for line in rfile]
        except OSError as ex:
            raise OchronaFileException(f"OS error when parsing {file_path}") from ex



from typing import List

from ochrona.const import INVALID_REQUIREMENTS_LINES
from ochrona.exceptions import OchronaFileException


class RequirementsFile:
    @staticmethod
    def parse(file_path: str) -> List[str]:
        """
        Parses a requirements.txt style file into a list of requirements.

        :param file_path: requirements*.txt file path.
        :return: list<str> list of dependencies ['dependency==semvar']
        """
        try:
            with open(file_path) as rfile:
                deps = [line.rstrip("\n") for line in rfile]
                return [
                    RequirementsFile.clean_dependency(dep)
                    for dep in deps
                    if not any(
                        [dep.strip().startswith(s) for s in INVALID_REQUIREMENTS_LINES]
                    )
                ]
        except OSError as ex:
            raise OchronaFileException(f"OS error when parsing {file_path}") from ex

    @staticmethod
    def clean_dependency(dependency: str) -> str:
        """
        Removes any comments or hashes following the dependency.

        :param file_path: a dependency with optional pinned version
        :return: str a cleaned dependency string
        """
        if " " in dependency or ";" in dependency or "#" in dependency:
            return dependency.split(" ")[0].replace(";", "")
        return dependency



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Ochrona-cli
:author: ascott
"""

import json
import sys

import click
from typing import Optional

from ochrona.config import OchronaConfig
from ochrona.exceptions import OchronaException, OchronaAPIException
from ochrona.file_handler import rfind_all_dependencies_files, parse_to_payload
from ochrona.import_wrapper import SafeImport
from ochrona.logger import OchronaLogger
from ochrona.reporter import OchronaReporter
from ochrona.ochrona_rest_client import OchronaAPIClient


@click.command()
@click.option("--api_key", help="Ochrona API Key (https://ochrona.dev).")
@click.option(
    "--dir",
    help="Directory to recursively search for dependencies files.",
    type=click.Path(exists=True),
)
@click.option("--file", "-r", help="Dependency file to use.", type=click.File("r"))
@click.option("--debug", help="Enable debug logging.", default=False, is_flag=True)
@click.option("--silent", help="Silent mode.", default=False, is_flag=True)
@click.option(
    "--report_type",
    help=f"The report type that's desired. Options ({OchronaConfig.REPORT_OPTIONS}",
    default="BASIC",
)
@click.option(
    "--output", help=f"Location for report output", type=click.Path(exists=True)
)
@click.option(
    "--exit",
    help="Exit with Code 0 regardless of vulnerability findings.",
    default=False,
    is_flag=True,
)
@click.option("--ignore", help="Ignore vulnerabilities by CVE or package name.")
@click.option(
    "--include_dev",
    help="Check dev dependencies in Pipfile.lock",
    default=False,
    is_flag=True,
)
@click.option("--project_name", help="The name of your project.")
@click.option(
    "--alert_config",
    help="The Alert configuration for your project. This should be a json string with quotation marks escaped.",
)
@click.option("--install", help="A safe wrapper for pip --install")
def run(
    api_key: Optional[str],
    dir: Optional[str],
    file: Optional[str],
    debug: bool,
    silent: bool,
    report_type: Optional[str],
    output: Optional[str],
    exit: bool,
    ignore: Optional[str],
    include_dev: bool,
    project_name: Optional[str],
    alert_config: Optional[str],
    install: Optional[str],
):
    config = OchronaConfig(
        api_key=api_key,
        dir=dir,
        file=file,
        debug=debug,
        silent=silent,
        report_type=report_type,
        report_location=output,
        exit=exit,
        ignore=ignore,
        include_dev=include_dev,
        project_name=project_name,
        alert_config=alert_config,
    )
    log = OchronaLogger(config=config)
    client = OchronaAPIClient(logger=log, config=config)
    if install:
        # Install mode
        try:
            importer = SafeImport(logger=log, client=client)
            importer.install(package=install)
        except OchronaException as ex:
            OchronaLogger.static_error(ex)
            sys.exit(1)
    else:
        # Regular operational check
        reporter = OchronaReporter(log, config)
        if not config.silent:
            log.header()

        files = rfind_all_dependencies_files(log, config.dir, config.file)

        try:
            results = []
            for file_ in files:
                payload = parse_to_payload(log, file_, config)
                if payload.get("dependencies") != []:
                    results.append(client.analyze(json.dumps(payload)))
                else:
                    # can't leave empty otherwise result counts are off
                    results.append(client.empty_result())
            if results == []:
                log.warn(f"No dependencies found in {files}")
            reporter.report_collector(files, results)
            if config.alert_config is not None and config.project_name is not None:
                client.update_alert(config=config)
        except OchronaAPIException as ex:
            OchronaLogger.static_error(ex)
            sys.exit(1)


if __name__ == "__main__":
    try:
        run()
    except OchronaException as ex:
        OchronaLogger.static_error(ex)
        sys.exit(1)



# -*- coding: utf-8 -*-
"""
Ochrona-cli
:author: ascott
"""
import platform
from ochrona import __version__


class OchronaLogger:
    HEADER = """{color}
 ▄▄▄▄▄▄▄▄▄▄▄  ▄▄▄▄▄▄▄▄▄▄▄  ▄         ▄  ▄▄▄▄▄▄▄▄▄▄▄  ▄▄▄▄▄▄▄▄▄▄▄  ▄▄        ▄  ▄▄▄▄▄▄▄▄▄▄▄ 
▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌▐░▌       ▐░▌▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌▐░░▌      ▐░▌▐░░░░░░░░░░░▌
▐░█▀▀▀▀▀▀▀█░▌▐░█▀▀▀▀▀▀▀▀▀ ▐░▌       ▐░▌▐░█▀▀▀▀▀▀▀█░▌▐░█▀▀▀▀▀▀▀█░▌▐░▌░▌     ▐░▌▐░█▀▀▀▀▀▀▀█░▌
▐░▌       ▐░▌▐░▌          ▐░▌       ▐░▌▐░▌       ▐░▌▐░▌       ▐░▌▐░▌▐░▌    ▐░▌▐░▌       ▐░▌
▐░▌       ▐░▌▐░▌          ▐░█▄▄▄▄▄▄▄█░▌▐░█▄▄▄▄▄▄▄█░▌▐░▌       ▐░▌▐░▌ ▐░▌   ▐░▌▐░█▄▄▄▄▄▄▄█░▌
▐░▌       ▐░▌▐░▌          ▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌▐░▌       ▐░▌▐░▌  ▐░▌  ▐░▌▐░░░░░░░░░░░▌
▐░▌       ▐░▌▐░▌          ▐░█▀▀▀▀▀▀▀█░▌▐░█▀▀▀▀█░█▀▀ ▐░▌       ▐░▌▐░▌   ▐░▌ ▐░▌▐░█▀▀▀▀▀▀▀█░▌
▐░▌       ▐░▌▐░▌          ▐░▌       ▐░▌▐░▌     ▐░▌  ▐░▌       ▐░▌▐░▌    ▐░▌▐░▌▐░▌       ▐░▌
▐░█▄▄▄▄▄▄▄█░▌▐░█▄▄▄▄▄▄▄▄▄ ▐░▌       ▐░▌▐░▌      ▐░▌ ▐░█▄▄▄▄▄▄▄█░▌▐░▌     ▐░▐░▌▐░▌       ▐░▌
▐░░░░░░░░░░░▌▐░░░░░░░░░░░▌▐░▌       ▐░▌▐░▌       ▐░▌▐░░░░░░░░░░░▌▐░▌      ▐░░▌▐░▌       ▐░▌
 ▀▀▀▀▀▀▀▀▀▀▀  ▀▀▀▀▀▀▀▀▀▀▀  ▀         ▀  ▀         ▀  ▀▀▀▀▀▀▀▀▀▀▀  ▀        ▀▀  ▀         ▀ 
                                                                                v. {version} {endc}
                                                                                https://ochrona.dev   
                                                                                        """

    INFO = "\033[94m"
    PASS = "\033[92m"
    WARNING = "\033[93m"
    ERROR = "\033[91m"
    ENDC = "\033[0m"
    BOLD = "\033[1m"
    UNDERLINE = "\033[4m"
    NO = ""

    def __init__(self, config):
        self._debug = config.debug
        self._silent = config.silent
        self._color = config.color_output

    def debug(self, val):
        if self._debug and not self._silent:
            print(
                f"{OchronaLogger.INFO if self._color else OchronaLogger.NO}[DEBUG] {val}{OchronaLogger.ENDC if self._color else OchronaLogger.NO}"
            )

    def info(self, val):
        if not self._silent:
            print(
                f"{OchronaLogger.INFO if self._color else OchronaLogger.NO}{val}{OchronaLogger.ENDC if self._color else OchronaLogger.NO}"
            )

    def warn(self, val):
        if not self._silent:
            print(
                f"{OchronaLogger.WARNING if self._color else OchronaLogger.NO}[!] {val}{OchronaLogger.ENDC if self._color else OchronaLogger.NO}"
            )

    def error(self, val):
        if not self._silent:
            print(
                f"{OchronaLogger.ERROR if self._color else OchronaLogger.NO}[!] {val}{OchronaLogger.ENDC if self._color else OchronaLogger.NO}"
            )

    @staticmethod
    def static_error(val):
        color = (
            OchronaLogger.ERROR if platform.system() != "Windows" else OchronaLogger.NO
        )
        endc = (
            OchronaLogger.ENDC if platform.system() != "Windows" else OchronaLogger.NO
        )
        print(f"{color}[!] {val}{endc}")

    @staticmethod
    def header():
        color = (
            OchronaLogger.INFO if platform.system() != "Windows" else OchronaLogger.NO
        )
        endc = (
            OchronaLogger.ENDC if platform.system() != "Windows" else OchronaLogger.NO
        )
        print(OchronaLogger.HEADER.format(color=color, version=__version__, endc=endc))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import sys
from setuptools import setup
from ochrona import __version__ as version


try:
    with open("README.md", encoding="utf8") as readme_file:
        readme = readme_file.read()
except TypeError:
    with open("README.md") as readme_file:
        readme = readme_file.read()

requirements = ["click>=7.1.2", "pyyaml>=5.3.1", "requests>=2.25.0", "toml>=0.10.2"]

test_requirements = ["pytest>=6.1.2", "pytest-vcr>=1.0.2"]

setup(
    name="ochrona",
    version=version,
    description="Ochrona checks your open source dependencies for vulnerabilities ",
    long_description=readme,
    long_description_content_type="text/markdown",
    author="Ochrona Security",
    author_email="andrew@ochrona.dev",
    url="https://github.com/ochorna/ochrona-cli",
    packages=["ochrona","ochrona.parsers"],
    package_dir={"ochrona": "ochrona"},
    entry_points={"console_scripts": ["ochrona=ochrona.cli:run"]},
    python_requires=">=3.6",
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords="ochrona, security, dependencies, vulnerability, testing",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    test_suite="tests",
    tests_require=test_requirements,
)
